Scientific And Statistical Formats
==================================

Handlers for scientific, statistical, and specialized dataset formats.

.. autosummary::
   :toctree: generated

   etlplus.file.dta
   etlplus.file.hdf5
   etlplus.file.mat
   etlplus.file.nc
   etlplus.file.rda
   etlplus.file.rds
   etlplus.file.sas7bdat
   etlplus.file.sav
   etlplus.file.sylk
   etlplus.file.xpt
   etlplus.file.zsav
